@@ -214,7 +214,31 @@ class Parametrizable(object):
         #~ cls.register_params()
         #~ return cls
       
+#~ class ActionRunner(object):
+class InstanceAction(object):
+    """
+    Wrapper object used to run actions from Python code.
+    """
+    def __init__(self,action,actor,instance,owner):
+        #~ print "Bar"
+        #~ self.action = action
+        self.bound_action = actor.get_action_by_name(action.action_name)
+        self.instance = instance
+        self.owner = owner
+        
+    #~ def __call__(self,ar,**kw):
+    def run_from_session(self,ses,**kw):
+        #~ print self,args, kw
+        ar = self.bound_action.request(**kw)
+        ar.setup_from(ses)
+        return self.bound_action.action.run_from_code(self.instance,ar)
 
+    #~ def as_button(self,obj,request,label=None):
+        #~ print "Foo"
+        #~ ba = self.defining_actor.get_url_action(self.action_name)
+        #~ btn = settings.SITE.ui.row_action_button(obj,request,ba,label)
+        #~ return E.tostring(btn)
+        
 
 class Action(Parametrizable,Permittable):
     """
@@ -249,7 +273,7 @@ class Action(Parametrizable,Permittable):
     value action
     ===== =================================
     10    :class:`insert <InsertRow>`
-    11    :attr:`duplicate <lino.mixins.duplicable.Duplicable.duplicate_row>`
+    11    :attr:`duplicate <lino.mixins.duplicable.Duplicable.duplicate>`
     20    :class:`detail <ShowDetailAction>`
     30    :class:`delete <DeleteSelected>`
     31    :class:`merge <lino.mixins.mergeable.Merge>`
@@ -426,7 +450,21 @@ class Action(Parametrizable,Permittable):
                 raise Exception("20130121 %s" % self)
             #~ assert isinstance(self.params_layout,self._layout_class)
             
+        if hasattr(self,'run'):
+            raise Exception(str(self))
+            
       
+    def __get__(self, instance, owner):
+        """
+        Getting an Action instance of an *Actor* (which is a class) will return the 
+        """
+        #~ print "__get__ %r / %r / %r" % (self, instance, owner)
+        if instance is None:
+            return self
+        return InstanceAction(self,instance.get_default_table(),instance,owner)
+        
+        
+        
     def as_html(self,ar):
         return "Oops, no as_html method for %s" % self
 
@@ -561,7 +599,10 @@ class Action(Parametrizable,Permittable):
         """
         return True
         
-    #~ def run(self,elem,ar,**kw):
+    def run_from_code(self,obj,ar,**kw):
+        return self.run_from_ui(obj,ar,**kw)
+        
+    #~ def run_from_ui(self,elem,ar,**kw):
         #~ raise NotImplementedError("%s has no run() method" % self.__class__)
 
     #~ def request(self,*args,**kw):
@@ -620,9 +661,9 @@ class RowAction(Action):
         h += ")"
         return h 
         
-    def run(self,row,ar,**kw):
+    def run_from_ui(self,row,ar,**kw):
         """
-        Execute the action on the given `row`. `ar` is an :class:`ActionRequest` 
+        Execute the action on the given `row`. `ar` is an :class:`ActionRequest <lino.core.requests.ActionRequest>` 
         object representing the context where the action is running.
         """
         raise NotImplementedError("%s has no run() method" % self.__class__)
@@ -950,7 +991,7 @@ class SubmitInsertAndStay(SubmitInsert):
     switch_to_detail = False
     action_name = 'poststay'
     label = _("Create without detail")
-    help_text = _("Don't open an detail window on the new record")
+    help_text = _("Don't open a detail window on the new record")
 
     
     
@@ -991,10 +1032,10 @@ class NotifyingAction(RowAction):
         if s is not None: kw.update(notify_body=s)
         return kw
         
-    def run(self,obj,ar,**kw):
+    def run_from_ui(self,obj,ar,**kw):
         kw.update(message=ar.action_param_values.notify_subject)
         kw.update(alert=True)
-        kw = super(NotifyingAction,self).run(obj,ar,**kw)
+        kw = super(NotifyingAction,self).run_from_ui(obj,ar,**kw)
         self.add_system_note(ar,obj)
         return kw
     
@@ -1025,7 +1066,7 @@ def action(*args,**kw):
         kw.setdefault('custom_handler',True)
         a = RowAction(*args,**kw)
         #~ a.run = curry(fn,a)
-        a.run = fn
+        a.run_from_ui = fn
         return a
     return decorator
         
