@@ -467,12 +467,23 @@ class Table(AbstractTable):
     """
     
     
+    #~ @classmethod
+    #~ def request(self,ui=None,request=None,action=None,**kw):
+        #~ if action is None:
+            #~ action = self.default_action
+            #~ assert action is not None
+        #~ return TableRequest(ui,self,request,action,**kw)
+        
     @classmethod
-    def request(self,ui=None,request=None,action=None,**kw):
-        if action is None:
-            action = self.default_action
-            assert action is not None
-        return TableRequest(ui,self,request,action,**kw)
+    def request(self,master_instance=None,**kw): # 20130327
+        kw.update(actor=self)
+        if master_instance is not None:
+            kw.update(master_instance=master_instance)
+        kw.setdefault('action',self.default_action)
+        #~ if action is None:
+            #~ action = self.default_action
+            #~ assert action is not None
+        return TableRequest(**kw)
         
     @classmethod
     def column_choices(self):
@@ -573,8 +584,6 @@ class Table(AbstractTable):
             self.hidden_elements = self.hidden_elements | self.model.hidden_elements
             
             
-        super(Table,self).class_init()
-        
         if self.model is not None:
               
             #~ for b in self.model.mro():
@@ -584,7 +593,12 @@ class Table(AbstractTable):
             if True:
                 for b in self.model.mro():
                     for k,v in b.__dict__.items():
+                        
+                        #~ if isinstance(v,actions.ActionRunner):
+                            #~ print "20130326 ActionRunner %s" % v
+                            #~ v = v.bound_action.action
                         if isinstance(v,actions.Action):
+                            #~ print "20130326 %s.%s = action %s from %s" % (self,k,v,b)
                             existing_value = self.__dict__.get(k,None)
                             if existing_value is not None:
                                 if not isinstance(existing_value,actions.Action):
@@ -667,6 +681,8 @@ class Table(AbstractTable):
         #~ else:
             #~ assert self.master is None
         
+        super(Table,self).class_init()
+        
         
         if self.order_by is not None:
             if not isinstance(self.order_by,(list,tuple)):
