@@ -284,6 +284,18 @@ class HtmlBox(DisplayField):
     
 #~ from django.db.models.fields import Field
 
+class VirtualGetter(object):
+    """
+    A wrapper object for getting the content of 
+    a virtual field programmatically. 
+    """
+    def __init__(self,vf,instance):
+        self.vf  = vf
+        self.instance = instance
+        
+    def __call__(self,ar=None):
+        return self.vf.value_from_object(self.instance,ar)
+        
 
 class VirtualField(FakeField): # (Field):
     """
@@ -324,10 +336,19 @@ class VirtualField(FakeField): # (Field):
             #~ if self.name != name:
                 #~ raise Exception("Tried to re-use %s.%s" % (actor_or_model,name))
         #~ self.name = name
+            
         if isinstance(self.return_type,basestring):
             self.return_type = resolve_field(self.return_type)
+            
+        #~ self.return_type.name = self.name
         if isinstance(self.return_type,models.ForeignKey):
-            self.return_type.rel.to = resolve_model(self.return_type.rel.to)
+            f = self.return_type
+            f.rel.to = resolve_model(f.rel.to)
+            #~ if f.name is None:
+            f.verbose_name = f.rel.to._meta.verbose_name
+                #~ from lino.core.kernel import set_default_verbose_name
+                #~ set_default_verbose_name(self.return_type)
+            
 
         #~ removed 20120919 self.return_type.editable = self.editable
         for k in ('''to_python choices save_form_data 
@@ -384,7 +405,7 @@ class VirtualField(FakeField): # (Field):
         
     def __get__(self,instance,owner):
         if instance is None: return self
-        return self.value_from_object(instance)
+        return VirtualGetter(self,instance)
         
     def __set__(self,instance,value):
         return self.set_value_in_object(None,instance,value)
