@@ -46,11 +46,12 @@ Extended Fields:
 
 Multilingual database content:
 
-- :class:`BabelNamed <north.dbutils.BabelNamed>`
+- :class:`BabelNamed <lino.mixins.BabelNamed>`
 - :class:`BabelCharField <north.dbutils.BabelCharField>`
 - :class:`BabelTextField <fields.BabelTextField>`
 - :class:`LanguageField <north.dbutils.LanguageField>`
 - :class:`babelkw <north.dbutils.babelkw>`
+- :class:`babelattr <north.dbutils.babelattr>`
 
 Virtual Fields:
 
@@ -82,6 +83,9 @@ Utilities:
 - :func:`update_field <lino.core.inject.update_field>` 
 - :func:`inject_field <lino.core.inject.inject_field>` 
 - :func:`inject_quick_add_buttons <lino.core.inject.inject_quick_add_buttons>` 
+- :func:`models_by_base <djangosite.dbutils.models_by_base>` 
+
+
 
 Signals:
 
@@ -193,11 +197,13 @@ from lino.core.fields import Constant, constant
 from lino.core.fields import ForeignKey
 from lino.core.fields import BabelTextField
 
-from north.dbutils import BabelCharField, BabelNamed, LanguageField
+from lino.mixins import BabelNamed
+
+from north.dbutils import BabelCharField, LanguageField
 from north.dbutils import babelkw
+from north.dbutils import babelattr
 from north.dbutils import babel_values # alias for babelkw for backward compat
 from north.dbutils import set_language
-from north.dbutils import dtos, dtosl
 #~ from north.dbutils import BabelCharField, BabelTextField, BabelNamed, LanguageField
 #~ from lino.core.fields import MethodField
 
@@ -281,3 +287,16 @@ class PseudoRequest:
     user = property(get_user)
     
 
+from lino.utils import IncompleteDate
+
+from north.dbutils import dtosl
+from north.dbutils import dtos as dtos_
+
+def dtos(d):
+    """
+    Also supports IncompleteDate
+    """
+    if isinstance(d,IncompleteDate):
+        return dtos_(d.as_date())
+    return dtos_(d)
+
