@@ -1,4 +1,4 @@
-﻿# -*- coding: UTF-8 -*-
+# -*- coding: UTF-8 -*-
 ## Copyright 2009-2013 Luc Saffre
 ## This file is part of the Lino project.
 ## Lino is free software; you can redistribute it and/or modify 
@@ -147,4 +147,4 @@ def objects():
     yield I(t,'language',u"""\
 Die Sprache, in der Dokumente ausgestellt werden sollen.
 """)
-    
\ No newline at end of file
+    
