@@ -24,13 +24,13 @@ from djangosite.utils.test import TestCase
 #from lino.igen import models
 #from lino.modlib.contacts.models import Contact, Companies
 #from lino.modlib.countries.models import Country
-from north import babel
+from north import dbutils
 
 from lino.core.dbutils import resolve_model,resolve_app
 Person = resolve_model("contacts.Person")
 #~ contacts = resolve_app('contacts')
 from lino.utils.instantiator import Instantiator, create_and_get
-from north.babel import babel_values
+from north.dbutils import babel_values
 
 from lino import mixins
 Genders = mixins.Genders
@@ -78,23 +78,23 @@ def test01(self):
         
     settings.SITE.uppercase_last_name = True
     
-    if 'en' in settings.SITE.AVAILABLE_LANGUAGES:
-        babel.set_language('en')
+    if settings.SITE.get_language_info('en'):
+        dbutils.set_language('en')
         self.assertEquals(luc.address(), u'''\
 Mr Luc SAFFRE
 Uus 1
 Vana-Vigala küla
 78003 Vigala
 Estonia''')
-    if 'de' in settings.SITE.AVAILABLE_LANGUAGES:
-        babel.set_language('de')
+    if settings.SITE.get_language_info('de'):
+        dbutils.set_language('de')
         self.assertEquals(luc.address(), u'''\
 Herrn Luc SAFFRE
 Uus 1
 Vana-Vigala küla
 78003 Vigala
 Estland''')
-    babel.set_language(None)
+    dbutils.set_language(None)
     
     
         
@@ -119,7 +119,7 @@ def test02(self):
     
     luc = Person.objects.get(name__exact="Saffre Luc")
     url = '/api/contacts/Person/%d?query=&an=detail&fmt=json' % luc.pk
-    if 'en' in settings.SITE.AVAILABLE_LANGUAGES:
+    if settings.SITE.get_language_info('en'):
         u.language = 'en'
         u.save()
         response = self.client.get(url,REMOTE_USER='root') # ,HTTP_ACCEPT_LANGUAGE='en')
@@ -127,7 +127,7 @@ def test02(self):
         self.assertEqual(result['data']['country'],"Estonia")
         self.assertEqual(result['data']['gender'],"Male")
     
-    if 'de' in settings.SITE.AVAILABLE_LANGUAGES:
+    if settings.SITE.get_language_info('de'):
         u.language = 'de'
         u.save()
         response = self.client.get(url,REMOTE_USER='root') # ,HTTP_ACCEPT_LANGUAGE='de')
@@ -141,7 +141,7 @@ def test02(self):
         self.assertEqual(result['data']['disabled_fields'],{'id': True})
         
         
-    if 'fr' in settings.SITE.AVAILABLE_LANGUAGES:
+    if settings.SITE.get_language_info('fr'):
         u.language = 'fr'
         u.save()
         response = self.client.get(url,REMOTE_USER='root') # ,HTTP_ACCEPT_LANGUAGE='fr')
