@@ -43,6 +43,8 @@ class Site(lino.Site):
     """
     """
     
+    console_user = None
+    
     partners_app_label = 'contacts'
     """
     Temporary setting, see :doc:`/tickets/72`
@@ -53,6 +55,12 @@ class Site(lino.Site):
     max_action_name_length = 50
     max_actor_name_length = 100
     
+    trusted_templates = False
+    """
+    Set this to True if you are sure that the users of your site won't try to 
+    misuse Jinja's capabilities.
+    """
+    
     #~ def add_config_value(self,name,default,help_text):
         #~ if not hasattr(self,name):
             #~ setattr(self,name,default)
@@ -197,7 +205,7 @@ class Site(lino.Site):
     django_admin_prefix = None
     """
     The prefix to use for Django admin URLs.
-    Leave this unchanged as long as :doc:`/ticket/70` is not solved.
+    Leave this unchanged as long as :doc:`/tickets/70` is not solved.
     """
     
     plain_prefix = '/plain' 
@@ -535,9 +543,6 @@ class Site(lino.Site):
     
     _site_config = None
     
-    #~ def init_nolocal(self,*args):
-        #~ super(Site,self).init_nolocal(*args)
-    
         
     def override_defaults(self,**kwargs):
         """
@@ -547,23 +552,6 @@ class Site(lino.Site):
         installed_apps = tuple(self.get_installed_apps()) + ('lino','djangosite')
         self.update_settings(INSTALLED_APPS=installed_apps)
         
-        modname = self.__module__
-        i = modname.rfind('.')
-        if i != -1:
-            modname = modname[:i]
-        self.is_local_project_dir = not modname in installed_apps
-            
-        """
-        If your project_dir contains no :xfile:`models.py`, 
-        but *does* contain a `fixtures` subdir, 
-        then Lino automatically adds this as "local fixtures directory" 
-        to Django's `FIXTURE_DIRS`.
-        """
-        if self.is_local_project_dir:
-            pth = join(self.project_dir,'fixtures')
-            if isdir(pth):
-                self.update_settings(FIXTURE_DIRS = [pth])
-                
         if self.webdav_url is None:
             self.webdav_url = '/media/webdav/'
         if self.webdav_root is None:
@@ -670,6 +658,19 @@ class Site(lino.Site):
 
         
       
+    #~ @property
+    #~ def site_config(self):
+        #~ SiteConfig = self.modules.ui.SiteConfig
+        #~ try:
+            #~ return SiteConfig.objects.get(pk=1)
+        #~ except SiteConfig.DoesNotExist:
+            #~ kw = dict(pk=1)
+            #~ kw.update(self.site_config_defaults)
+            #~ sc = SiteConfig(**kw)
+            #~ sc.full_clean()
+            #~ sc.save()
+            #~ return sc
+      
     @property
     def site_config(self):
         """
@@ -678,21 +679,20 @@ class Site(lino.Site):
         If no instance exists (which happens in a virgin database),
         we create it using default values from :attr:`site_config_defaults`.
         
-        This property may not be used as long as there is no database 
-        connected (or not initialized).
-        
         """
         if self._site_config is None:
             #~ raise Exception(20130301)
-            #~ print '20120801 create _site_config'
-            from lino.core.dbutils import resolve_model
+            #~ print '20130320 create _site_config'
+            #~ from lino.core.dbutils import resolve_model
+            #~ from lino.core.dbutils import obj2str
             #~ from lino.utils import dblogger as logger
-            SiteConfig = resolve_model('ui.SiteConfig')
+            #~ SiteConfig = resolve_model('ui.SiteConfig')
+            SiteConfig = self.modules.ui.SiteConfig
             #~ from .models import SiteConfig
             #~ from django.db.utils import DatabaseError
             try:
-                self._site_config = SiteConfig.objects.get(pk=1)
-                #~ logger.info("20130301 Loaded SiteConfig record (%s)",self._site_config)
+                self._site_config = SiteConfig.real_objects.get(pk=1)
+                #~ print "20130301 Loaded SiteConfig record", obj2str(self._site_config,True)
             #~ except (SiteConfig.DoesNotExist,DatabaseError):
             except SiteConfig.DoesNotExist:
             #~ except Exception,e:
@@ -700,7 +700,7 @@ class Site(lino.Site):
                 #~ kw.update(settings.SITE.site_config_defaults)
                 kw.update(self.site_config_defaults)
                 self._site_config = SiteConfig(**kw)
-                #~ logger.info("20130301 Created SiteConfig record (%s)",self._site_config)
+                #~ print "20130301 Created SiteConfig record", obj2str(self._site_config,True)
                 # 20120725 
                 # polls_tutorial menu selection `Config --> Site Parameters` 
                 # said "SiteConfig 1 does not exist"
@@ -713,16 +713,20 @@ class Site(lino.Site):
         """
         Clear the cached SiteConfig instance. 
         
-        This is needed e.g. when the test runner has created the test database.
+        This is needed e.g. when the test runner has created a new 
+        test database.
         """
         self._site_config = None
+        #~ print "20130320 clear_site_config"
     
-    def on_site_config_saved(self,sc):
-        """
-        Used internally. Called by SiteConfig.save() to update the cached instance.
-        """
-        self._site_config = sc
-        #~ print '20120801 site_config saved', sc.propgroup_softskills
+    #~ def on_site_config_saved(self,sc):
+        #~ """
+        #~ Used internally. Called by SiteConfig.save() to update the cached instance.
+        #~ """
+        #~ pass
+        #~ self._site_config = sc
+        #~ from lino.core.dbutils import obj2str
+        #~ print '20120801 site_config saved', obj2str(sc,True)
         
     def is_imported_partner(self,obj):
         """
@@ -820,7 +824,7 @@ class Site(lino.Site):
         for defining :setting:`MIDDLEWARE_CLASSES`, 
         you can simply set :setting:`MIDDLEWARE_CLASSES`
         in your :xfile:`settings.py` 
-        after the :class:`lino.Site` has been initialized.
+        after the :class:`lino.Site` has been instantiated.
         
         `Django and standard HTTP authentication
         <http://stackoverflow.com/questions/152248/can-i-use-http-basic-authentication-with-django>`_
@@ -983,3 +987,13 @@ class Site(lino.Site):
         return sep.join(['<a href="%s" target="_blank">%s</a>&nbsp;%s' 
             % (u,n,v) for n,v,u in self.using(ui)])
 
+    def login(self,username):
+        #~ self.console_user = self.user_model.objects.get(username=username)
+        u = self.user_model.objects.get(username=username)
+        from lino.core import requests
+        if u.language:
+            from north.dbutils import set_language
+            set_language(u.language)
+        return requests.BaseRequest(renderer=self.ui.text_renderer,
+            user=u)
+        
