@@ -284,6 +284,12 @@ class HtmlRenderer(object):
         return xghtml.E.b(text)
         
 class TextRenderer(HtmlRenderer):
+    user = None
+    
+    def __init__(self,ui):
+        HtmlRenderer.__init__(self,ui)
+        self.user = None
+        
     def instance_handler(self,ar,obj):
         return None
     def pk2url(self,ar,pk,**kw):
@@ -294,8 +300,29 @@ class TextRenderer(HtmlRenderer):
         if text is None:
             text = '#'
         return text
+        
+    def show(self,ar,*args,**kw):
+        print ar.to_rst(*args,**kw)
+        
+        
+    def unused_request(self,actor=None,**kw):
+        #~ username = kw.pop('username',None)
+        #~ if username:
+            #~ self.login(username)
+        #~ if self.user:
+            #~ kw.setdefault('user',self.user)
+        kw.setdefault('user',settings.SITE.console_user)
+        kw.update(renderer=self)
+        #~ raise Exception(kw)
+        return actor.request(**kw)
+        
   
 class PlainRenderer(HtmlRenderer):
+    """
+    A "plain" HTML render that uses bootstrap and jQuery.
+    It is called "plain" because that's much more lightweight than 
+    :class:`lino.extjs.ExtRenderer`.
+    """
   
     is_interactive = True
     
