@@ -116,10 +116,11 @@ class ExtUI(base.UI):
     """
     The central instance of Lino's ExtJS3 User Interface.
     """
-    _handle_attr_name = '_extjs3_handle'
+    #~ _handle_attr_name = '_extjs3_handle'
+    _handle_attr_name = '_lino_ui_handle'
     #~ _response = None
-    name = 'extjs3'
-    verbose_name = "ExtJS with Windows"
+    #~ name = 'extjs3'
+    #~ verbose_name = "ExtJS with Windows"
     #~ Panel = ext_elems.Panel
     
     
@@ -135,13 +136,19 @@ class ExtUI(base.UI):
         
         #~ raise Exception("20120614")
         #~ self.pdf_renderer = PdfRenderer(self) # 20120624
-        from lino_extjs import ExtRenderer
-        self.ext_renderer = ExtRenderer(self)
         from .render import PlainRenderer, TextRenderer
         self.plain_renderer = PlainRenderer(self)
         self.text_renderer = TextRenderer(self)
         self.reserved_names = [getattr(ext_requests,n) for n in ext_requests.URL_PARAMS]
           
+        if settings.SITE.use_extjs:
+            from lino.extjs import ExtRenderer
+            self.default_renderer = self.ext_renderer = ExtRenderer(self)
+        else:
+            self.default_renderer = self.plain_renderer
+            
+          
+          
         names = set()
         for n in self.reserved_names:
             if n in names:
