@@ -57,19 +57,27 @@ from . import elems as ext_elems
 
 MAX_ROW_COUNT = 300
 
-E = xghtml.E
 
-pages = dd.resolve_app('pages')
 
 class HttpResponseDeleted(http.HttpResponse):
     status_code = 204
     
 
 def requested_actor(app_label,actor):
+    """
+    Utility function which returns the requested actor, 
+    either directly or (if specified name is a model) that 
+    model's default actor.
+    """
     x = getattr(settings.SITE.modules,app_label)
     cl = getattr(x,actor)
-    if issubclass(cl,dd.Model):
+    if not isinstance(cl,type):
+        raise Exception("%s.%s is not a class" % (app_label,actor))
+    if issubclass(cl,models.Model):
         return cl._lino_default_table
+    if not issubclass(cl,actors.Actor):
+        #~ raise http.Http404("%r is not an actor" % cl)
+        raise Exception("%r is not an actor" % cl)
     return cl
     
 #~ class Http403(Exception):
@@ -93,13 +101,13 @@ def action_request(app_label,actor,request,rqdata,is_list,**kw):
         raise exceptions.PermissionDenied(
             _("As %s you have no permission to run this action.") % user.profile)
         #~ return http.HttpResponseForbidden(_("As %s you have no permission to run this action.") % user.profile)
-    ar = rpt.request(settings.SITE.ui,request,a,**kw)
+    ar = rpt.request(request=request,action=a,**kw)
     #~ ar.renderer = settings.SITE.ui.ext_renderer
     return ar
     
 def run_action(ar,elem):
     try:
-        rv = ar.bound_action.action.run(elem,ar)
+        rv = ar.bound_action.action.run_from_ui(elem,ar)
         if rv is None:
             rv  = ui.success()
         return ar.ui.action_response(rv)
@@ -323,7 +331,7 @@ def form2obj_and_save(ar,data,elem,is_new,restful,file_upload=False): # **kw2sav
     #~ self = settings.SITE.ui
     request = ar.request
     rh = ar.ah
-    #~ logger.info('20120814 form2obj_and_save %r', data)
+    #~ logger.info('20130321 form2obj_and_save %r', data)
     #~ print 'form2obj_and_save %r' % data
     
     #~ logger.info('20120228 before store.form2obj , elem is %s' % dd.obj2str(elem))
@@ -443,11 +451,13 @@ class Authenticate(View):
     def get(self, request, *args, **kw):
         action_name = request.GET.get(ext_requests.URL_PARAM_ACTION_NAME)
         if action_name == 'logout':
-            username = request.session['username'] 
-            del request.session['username'] 
-            del request.session['password']
-            rv = dict(success=True,message="%r has been logged out" % username)
+            username = request.session.pop('username',None)
+            request.session.pop('password',None)
+            #~ username = request.session['username']
+            #~ del request.session['password']
+            rv = dict(success=True,message="User %r logged out." % username)
             return settings.SITE.ui.action_response(rv)
+        raise http.Http404()
             
 
     def post(self, request, *args, **kw):
@@ -466,7 +476,6 @@ class Authenticate(View):
         #~ auth.login(request,request.GET.get('username'), request.GET.get('password'))
         #~ ss.save()
         rv = settings.SITE.ui.success("Now logged in as %r" % username)
-        #~ rv = dict(success=True,message="Now logged in as %r" % username)
         return settings.SITE.ui.action_response(rv)
       
 
@@ -490,44 +499,64 @@ class Callbacks(View):
         return settings.SITE.ui.callback_get(request,thread_id,button_id)
         
 
-class Templates(View):
-  
-    #~ def templates_view(self,request,
-    def get(self,request,
-        app_label=None,actor=None,pk=None,fldname=None,tplname=None,**kw):
-      
-        if request.method == 'GET':
-            from lino.models import TextFieldTemplate
-            if tplname:
-                tft = TextFieldTemplate.objects.get(pk=int(tplname))
-                return http.HttpResponse(tft.text)
-                
-            rpt = requested_actor(app_label,actor)
-                
-            elem = rpt.get_row_by_pk(pk)
 
-                
-            if elem is None:
-                raise http.Http404("%s %s does not exist." % (rpt,pk))
-                
-            #~ TextFieldTemplate.templates
-            m = getattr(elem,"%s_templates" % fldname,None)
-            if m is None:
-                q = models.Q(user=request.user) | models.Q(user=None)
-                #~ q = models.Q(user=request.user)
-                qs = TextFieldTemplate.objects.filter(q).order_by('name')
-            else:
-                qs = m(request)
-                
-            templates = []
-            for obj in qs:
-                url = settings.SITE.build_admin_url('templates',
-                    app_label,actor,pk,fldname,unicode(obj.pk))
-                templates.append([
-                    unicode(obj.name),url,unicode(obj.description)])
-            js = "var tinyMCETemplateList = %s;" % py2js(templates)
-            return http.HttpResponse(js,content_type='text/json')
-        raise http.Http404("Method %r not supported" % request.method)
+#~ if settings.SITE.user_model:
+if settings.SITE.user_model and settings.SITE.use_tinymce:
+  
+    from jinja2 import Template as JinjaTemplate
+    from lino.ui.models import TextFieldTemplate
+
+    class Templates(View):
+      """
+      Called by TinyMCE (`template_external_list_url 
+      <http://www.tinymce.com/wiki.php/configuration:external_template_list_url>`_)
+      to fill the list of available templates.
+      
+      """
+      #~ def templates_view(self,request,
+      def get(self,request,
+          app_label=None,actor=None,pk=None,fldname=None,tplname=None,**kw):
+        
+          
+          if request.method == 'GET':
+            
+              rpt = requested_actor(app_label,actor)
+              elem = rpt.get_row_by_pk(pk)
+              if elem is None:
+                  raise http.Http404("%s %s does not exist." % (rpt,pk))
+                  
+              if tplname:
+                  tft = TextFieldTemplate.objects.get(pk=int(tplname))
+                  if settings.SITE.trusted_templates:
+                      #~ return http.HttpResponse(tft.text)
+                      template = JinjaTemplate(tft.text)
+                      context = dict(request=request,instance=elem,**settings.SITE.modules)
+                      return http.HttpResponse(template.render(**context))
+                  else:
+                      return http.HttpResponse(tft.text)
+                  
+                  
+              #~ q = models.Q(user=request.user) | models.Q(user__group__in=request.user.group_set.all())
+              teams = [o.group for o in request.user.users_membership_set_by_user.all()]
+              flt = models.Q(team__isnull=True) | models.Q(team__in=teams)
+              qs = TextFieldTemplate.objects.filter(flt).order_by('name')
+                  
+              #~ m = getattr(elem,"%s_templates" % fldname,None)
+              #~ if m is None:
+                  #~ q = models.Q(user=request.user) | models.Q(user=None)
+                  #~ qs = TextFieldTemplate.objects.filter(q).order_by('name')
+              #~ else:
+                  #~ qs = m(request)
+                  
+              templates = []
+              for obj in qs:
+                  url = settings.SITE.build_admin_url('templates',
+                      app_label,actor,pk,fldname,unicode(obj.pk))
+                  templates.append([
+                      unicode(obj.name),url,unicode(obj.description)])
+              js = "var tinyMCETemplateList = %s;" % py2js(templates)
+              return http.HttpResponse(js,content_type='text/json')
+          raise http.Http404("Method %r not supported" % request.method)
 
 
 
@@ -576,7 +605,7 @@ def choices_for_field(request,rpt,field):
     elif isinstance(field,models.ForeignKey):
         m = field.rel.to
         t = getattr(m,'_lino_choices_table',m._lino_default_table)
-        qs = t.request(settings.SITE.ui,request).data_iterator
+        qs = t.request(request=request).data_iterator
         #~ logger.info('20120710 choices_view(FK) %s --> %s',t,qs)
         def row2dict(obj,d):
             d[ext_requests.CHOICES_TEXT_FIELD] = obj.get_choices_text(request,rpt,field)
@@ -646,7 +675,7 @@ class Choices(View):
         rpt = requested_actor(app_label,rptname)
         emptyValue = None
         if fldname is None:
-            ar = rpt.request(settings.SITE.ui,request) # ,rpt.default_action)
+            ar = rpt.request(request=request) # ,rpt.default_action)
             #~ rh = rpt.get_handle(self)
             #~ ar = ViewReportRequest(request,rh,rpt.default_action)
             #~ ar = dbtables.TableRequest(self,rpt,request,rpt.default_action)
@@ -682,14 +711,14 @@ class Restful(View):
     """
   
     def post(self,request,app_label=None,actor=None,pk=None):
-        ui = settings.SITE.ui
+        #~ ui = settings.SITE.ui
         rpt = requested_actor(app_label,actor)
         #~ a = rpt.default_action
         if pk is None:
             elem = None
         else:
             elem = rpt.get_row_by_pk(pk)
-        ar = rpt.request(ui,request)
+        ar = rpt.request(request=request)
             
         instance = ar.create_instance()
         # store uploaded files. 
@@ -706,15 +735,15 @@ class Restful(View):
         
       
     def delete(self,request,app_label=None,actor=None,pk=None):
-        ui = settings.SITE.ui
+        #~ ui = settings.SITE.ui
         rpt = requested_actor(app_label,actor)
         #~ a = rpt.default_action
         elem = rpt.get_row_by_pk(pk)
-        ar = rpt.request(ui,request)
+        ar = rpt.request(request=request)
         return delete_element(ar,elem)
       
     def get(self,request,app_label=None,actor=None,pk=None):
-        ui = settings.SITE.ui
+        #~ ui = settings.SITE.ui
         rpt = requested_actor(app_label,actor)
         #~ a = rpt.default_action
         assert pk is None, 20120814
@@ -722,7 +751,7 @@ class Restful(View):
             #~ elem = None
         #~ else:
             #~ elem = rpt.get_row_by_pk(pk)
-        ar = rpt.request(ui,request)
+        ar = rpt.request(request=request)
         rh = ar.ah
         rows = [ 
           rh.store.row2dict(ar,row,rh.store.list_fields) 
@@ -730,17 +759,17 @@ class Restful(View):
         return json_response_kw(count=ar.get_total_count(),rows=rows)
         
     def put(self,request,app_label=None,actor=None,pk=None):
-        ui = settings.SITE.ui
+        #~ ui = settings.SITE.ui
         rpt = requested_actor(app_label,actor)
         #~ a = rpt.default_action
         elem = rpt.get_row_by_pk(pk)
-        ar = rpt.request(ui,request)
+        ar = rpt.request(request=request)
         rh = ar.ah
             
         data = http.QueryDict(request.body).get('rows') # raw_post_data before Django 1.4
         data = json.loads(data)
         a = rpt.get_url_action(rpt.default_list_action_name)
-        ar = rpt.request(ui,request,a)
+        ar = rpt.request(request=request,action=a)
         ar.renderer = ui.ext_renderer
         return form2obj_and_save(ar,data,elem,False,True) # force_update=True)
           
@@ -778,7 +807,7 @@ class ApiElement(View):
             raise http.Http404("%s has no action %r" % (rpt,action_name))
             
         #~ ar = rpt.request(ui,request,a)
-        ar = ba.request(ui,request)
+        ar = ba.request(request=request)
         ar.renderer = ui.ext_renderer
         ah = ar.ah
         
@@ -848,12 +877,12 @@ class ApiElement(View):
         return form2obj_and_save(ar,data,elem,False,False) # force_update=True)
             
     def delete(self,request,app_label=None,actor=None,pk=None):
-        ui = settings.SITE.ui
+        #~ ui = settings.SITE.ui
         rpt = requested_actor(app_label,actor)
         elem = rpt.get_row_by_pk(pk)
         if elem is None:
             raise http.Http404("%s has no row with primary key %r" % (rpt,pk))
-        ar = rpt.request(ui,request)
+        ar = rpt.request(request=request)
         return delete_element(ar,elem)
         
 
@@ -885,7 +914,7 @@ class ApiList(View):
         ar = action_request(app_label,actor,request,request.POST,True)
         ar.renderer = settings.SITE.ui.ext_renderer
         #~ print 20121116, ar.bound_action.action.action_name
-        if ar.bound_action.action.action_name in ['duplicate_row','post','poststay','insert']:
+        if ar.bound_action.action.action_name in ['duplicate','post','poststay','insert']:
         #~ if isinstance(ar.bound_action.action,(
               #~ actions.InsertRow,
               #~ actions.DuplicateAction,
@@ -995,7 +1024,7 @@ class ApiList(View):
             #~ ar.renderer = ui.ext_renderer
             response = http.HttpResponse(content_type='text/html;charset="utf-8"')
             doc = xghtml.Document(force_unicode(ar.get_title()))
-            doc.body.append(xghtml.E.h1(doc.title))
+            doc.body.append(E.h1(doc.title))
             t = doc.add_table()
             ar.ui.ar2html(ar,t,ar.data_iterator)
             doc.write(response,encoding='utf-8')
@@ -1082,7 +1111,9 @@ class PlainList(View):
         
 
 class PlainElement(View):
-  
+    """
+    Render a single record from :class:`lino.ui.PlainRenderer`.
+    """
     def get(self,request,app_label=None,actor=None,pk=None):
         """
         GET : Retrieve a representation of the addressed member of the collection expressed in an appropriate MIME type.
@@ -1126,8 +1157,9 @@ class PlainIndex(View):
         if a is not None:
             if not a.get_view_permission(user.profile):
                 raise exceptions.PermissionDenied("Action not allowed for %s" % user)
-            ar = a.request(settings.SITE.ui,request,**kw)
-            ar.renderer = ui.plain_renderer
+            kw.update(renderer=ui.plain_renderer)
+            ar = a.request(request=request,**kw)
+            #~ ar.renderer = ui.plain_renderer
             context.update(title=ar.get_title())
             # TODO: let ar generate main
             # context.update(main=ui.plain_renderer.action_call(request,a,{}))
