@@ -32,11 +32,12 @@ the only thing needed by
 One possibility might be to write a special Jinja Template class...
 
 Die Reihenfolge in :setting:`INSTALLED_APPS` sollte sein: zuerst 
-`django.contrib.*`, dann ``lino``, dann `lino.modlib.*` und dann `lino.apps.pcsw`. 
+`django.contrib.*`, dann ``lino``, dann `lino.modlib.*` 
+und dann `lino.projects.pcsw`. 
 Also vom Allgemeineren zum Spezifischeren. Und bei den config-Dirs soll diese 
 Liste umgekehrt abgeklappert werden (und die Suche beim 
 ersten Treffer aufhören): zuerst das eventuelle lokale `config_dir`, 
-dann `lino.apps.pcsw`, dann die diversen `lino.modlib.*` usw. 
+dann `lino.projects.pcsw`, dann die diversen `lino.modlib.*` usw. 
 
 """
 
@@ -54,7 +55,6 @@ from fnmatch import fnmatch
 from django.conf import settings
 from django.utils.importlib import import_module
 
-from lino.core.modeltools import makedirs_if_missing
 from lino.utils import iif
 
 SUBDIR_NAME = 'config' # we might change this to "templates" 
@@ -83,12 +83,11 @@ for app in settings.INSTALLED_APPS:
 
 LOCAL_CONFIG_DIR = None
 
+#~ for dirname in settings.SITE.get_settings_subdirs(SUBDIR_NAME)
 
-if settings.LINO.project_dir != settings.LINO.source_dir:
-    """
-    When called by makedocs, there is no local config dir.
-    """
-    dirname = os.path.join(settings.LINO.project_dir,SUBDIR_NAME)
+#~ if settings.SITE.project_dir != settings.SITE.source_dir:
+if settings.SITE.is_local_project_dir:
+    dirname = os.path.join(settings.SITE.project_dir,SUBDIR_NAME)
     if os.path.isdir(dirname):
         LOCAL_CONFIG_DIR = ConfigDir(dirname,True)
         config_dirs.append(LOCAL_CONFIG_DIR)
@@ -228,7 +227,7 @@ class Configured(object):
             self.cd = LOCAL_CONFIG_DIR
         fn = os.path.join(self.cd.name,self.filename)
         dirname = os.path.dirname(fn)
-        makedirs_if_missing(dirname)
+        settings.SITE.makedirs_if_missing(dirname)
         #~ if not os.path.exists(dirname):
             #~ os.makedirs(dirname)
         f = codecs.open(fn,'w',encoding='utf-8')
